==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/CREDENTIAL_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CREDENTIAL_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CREDENTIAL_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTNERUSERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTNERPASSWORD" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CREDENTIAL_Type", propOrder = {
    "partnerusercode",
    "partnerpassword"
})
public class CREDENTIAL_Type {

    @XmlElement(name = "PARTNERUSERCODE", required = true)
    protected String partnerusercode;
    @XmlElement(name = "PARTNERPASSWORD")
    protected String partnerpassword;

    /**
     * Obtient la valeur de la propriété partnerusercode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTNERUSERCODE() {
        return partnerusercode;
    }

    /**
     * Définit la valeur de la propriété partnerusercode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTNERUSERCODE(String value) {
        this.partnerusercode = value;
    }

    /**
     * Obtient la valeur de la propriété partnerpassword.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTNERPASSWORD() {
        return partnerpassword;
    }

    /**
     * Définit la valeur de la propriété partnerpassword.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTNERPASSWORD(String value) {
        this.partnerpassword = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/CREDENTIAL_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CREDENTIAL_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CREDENTIAL_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTNERUSERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTNERPASSWORD" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CREDENTIAL_Type", propOrder = {
    "partnerusercode",
    "partnerpassword"
})
public class CREDENTIAL_Type {

    @XmlElement(name = "PARTNERUSERCODE", required = true)
    protected String partnerusercode;
    @XmlElement(name = "PARTNERPASSWORD")
    protected String partnerpassword;

    /**
     * Gets the value of the partnerusercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTNERUSERCODE() {
        return partnerusercode;
    }

    /**
     * Sets the value of the partnerusercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTNERUSERCODE(String value) {
        this.partnerusercode = value;
    }

    /**
     * Gets the value of the partnerpassword property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTNERPASSWORD() {
        return partnerpassword;
    }

    /**
     * Sets the value of the partnerpassword property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTNERPASSWORD(String value) {
        this.partnerpassword = value;
    }

}
